# `tg-store-cli`

TG Store CLI

**Usage**:

```console
$ tg-store-cli [OPTIONS] COMMAND [ARGS]...
```

**Options**:

* `--install-completion`: Install completion for the current shell.
* `--show-completion`: Show completion for the current shell, to copy it or customize the installation.
* `--help`: Show this message and exit.

**Commands**:

* `load`: Зарядка
* `shoot`: Стрельба

## `tg-store-cli load`

Зарядка

**Usage**:

```console
$ tg-store-cli load [OPTIONS]
```

**Options**:

* `--help`: Show this message and exit.

## `tg-store-cli shoot`

Стрельба 

**Usage**:

```console
$ tg-store-cli shoot [OPTIONS]
```

**Options**:

* `--help`: Show this message and exit.
